# Generated by roxygen2: do not edit by hand

S3method(print,energy_burden_comparison)
export("%>%")
export(calculate_weighted_metrics)
export(check_data_sources)
export(clear_all_cache)
export(clear_dataset_cache)
export(colorize)
export(compare_energy_burden)
export(dear_func)
export(energy_burden_func)
export(eroi_func)
export(get_dataset_info)
export(get_income_brackets)
export(lead_to_poverty)
export(list_cohort_columns)
export(list_income_brackets)
export(list_states)
export(load_census_tract_data)
export(load_cohort_data)
export(neb_func)
export(ner_func)
export(process_lead_cohort_data)
export(raw_to_lead)
export(to_big)
export(to_billion_dollar)
export(to_dollar)
export(to_million)
export(to_percent)
importFrom(dplyr,"%>%")
importFrom(stats,weighted.mean)
