% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lead_data_loaders.R
\name{check_data_sources}
\alias{check_data_sources}
\title{Check Available Data Sources}
\usage{
check_data_sources(verbose = TRUE)
}
\arguments{
\item{verbose}{Logical, print detailed status (default TRUE)}
}
\value{
A list with status of each data source
}
\description{
Check which data sources are available locally (database, CSV files, or
will require download from OpenEI).
}
\examples{
\donttest{
# Check what data is available
check_data_sources()
}
}
