% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/database-helpers.R
\name{get_db_path}
\alias{get_db_path}
\title{Get Database Path}
\usage{
get_db_path(test = FALSE)
}
\arguments{
\item{test}{Logical, whether to use test database (default FALSE)}
}
\value{
Path to database file
}
\description{
Returns the path to the database, with protection against accidental deletion.
For tests, use a separate test database.
}
\keyword{internal}
