% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/energy_ratios.R
\name{dear_func}
\alias{dear_func}
\title{Calculate Disposable Energy-Adjusted Resources (DEAR)}
\usage{
dear_func(g, s, se = NULL)
}
\arguments{
\item{g}{Numeric vector of gross income values}

\item{s}{Numeric vector of energy spending values}

\item{se}{Optional numeric vector of effective energy spending (defaults to s)}
}
\value{
Numeric vector of DEAR values (ratio of disposable income to gross income)
}
\description{
Calculates DEAR as the ratio of net income after energy spending to
gross income. DEAR = (G - S) / G.
}
\examples{
# Calculate DEAR
dear_func(50000, 3000)
}
