% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lead_data_loaders.R
\name{find_emburden_db}
\alias{find_emburden_db}
\title{Find emburden_db.sqlite database}
\usage{
find_emburden_db()
}
\description{
Find emburden_db.sqlite database
}
\keyword{internal}
